﻿<%@ Page Title="ASP.NET SignalR: Connection API" Language="C#" MasterPageFile="~/SignalR.Master" AutoEventWireup="true" CodeBehind="Default.aspx.cs" Inherits="Microsoft.AspNet.SignalR.Samples.Raw.Default" %>

<asp:Content runat="server" ContentPlaceHolderID="MainContent">
    <ul class="breadcrumb">
        <li><a href="<%: ResolveUrl("~/") %>">SignalR示例</a> <span class="divider">/</span></li>
        <li class="active">连接接口</li>
    </ul>

    <div class="page-header">
        <h2>连接接口<small>底层连接</small></h2>
        <p>底层连接全部特性的示例，包括：连接的启动和停止，发送和接收消息，还有管理组。</p>
    </div>

    <a href="crossdomain.htm">跨域示例</a>

    <h4>发给每个人</h4>
    <form class="form-inline">
        <div class="input-append">
            <input type="text" id="msg" placeholder="输入消息, 名字或组" />
            <input type="button" id="broadcast" class="btn" value="广播" />
            <input type="button" id="broadcast-exceptme" class="btn" value="广播（除我之外）" />
            <input type="button" id="join" class="btn" value="设置名字" />
            <input type="button" id="join-group" class="btn" value="加入组" />
            <input type="button" id="leave-group" class="btn" value="离开组" />
        </div>
    </form>

    <h4>发给我</h4>
    <form class="form-inline">
        <div class="input-append">
            <input type="text" id="me" placeholder="输入消息" />
            <input type="button" id="send" class="btn" value="发给我" />
        </div>
    </form>

    <h4>私有消息</h4>
    <form class="form-inline">
        <div class="input-prepend input-append">
            <input type="text" name="message" id="message" placeholder="输入消息" />
            <input type="text" name="user" id="user" placeholder="输入一个用户或组名" />

            <input type="button" id="privatemsg" class="btn" value="发给用户" />
            <input type="button" id="groupmsg" class="btn" value="发给组" />
        </div>
    </form>

    <button id="stopStart" class="btn btn-info btn-small" disabled="disabled"><i class="icon-stop icon-white"></i><span>停止连接</span></button>

    <h4>消息展示</h4>
    <ul id="messages">
    </ul>
</asp:Content>

<asp:Content runat="server" ContentPlaceHolderID="Scripts">
    <script src="<%: ResolveUrl("~/Scripts/jquery.cookie.js") %>"></script>
    <script>
        $(function () {
            "use strict";

            // 创建连接
            var connection = $.connection("raw-connection");
            connection.logging = true;

            // 接收
            connection.received(function (data) {
                $("<li/>").css("background-color", "blue")
                    .css("color", "white")
                    .html(window.JSON.stringify(data)).appendTo($("#messages"));

                if (data.type === 'Join') {
                    $.cookie('user', data.data, { path: "/" });
                }
            });

            // 重连
            connection.reconnected(function () {
                $("<li/>").css("background-color", "green")
                    .css("color", "white")
                    .html("[" + new Date().toTimeString() + "]: Connection re-established")
                    .appendTo($("#messages"));
            });

            // 连接错误
            connection.error(function (err) {
                $("<li/>").css("background-color", "red")
                    .css("color", "white")
                    .html(err || "Error occurred")
                    .appendTo($("#messages"));
            });

            // 断开
            connection.disconnected(function () {
                $("#stopStart")
                    .prop("disabled", false)
                    .find("span")
                    .text("开始连接")
                    .end()
                    .find("i")
                    .removeClass("icon-stop")
                    .addClass("icon-play");
            });

            // 状态改变
            connection.stateChanged(function (change) {
                var oldState = null,
                    newState = null;
                for (var p in $.signalR.connectionState) {
                    if ($.signalR.connectionState[p] === change.oldState) {
                        oldState = p;
                    }

                    if ($.signalR.connectionState[p] === change.newState) {
                        newState = p;
                    }
                }

                $("<li/>").css("background-color", "orange")
                    .css("color", "white")
                    .html(oldState + " => " + newState)
                    .appendTo($("#messages"));
            });

            var start = function () {
                connection.start({ transport: activeTransport, jsonp: isJsonp })
                    .then(function () {
                        $("#stopStart")
                            .prop("disabled", false)
                            .find("span")
                            .text("停止连接")
                            .end()
                            .find("i")
                            .removeClass("icon-play")
                            .addClass("icon-stop");
                    });
            };
            start();

            // 发给我
            $("#send").click(function () {
                connection.send({ type: 0, value: $("#me").val() });
            });

            // 广播
            $("#broadcast").click(function () {
                connection.send({ type: 1, value: $("#msg").val() });
            });

            // 广播（除我之外）
            $("#broadcast-exceptme").click(function () {
                connection.send({ type: 7, value: $("#msg").val() });
            });

            // 设置名字
            $("#join").click(function () {
                connection.send({ type: 2, value: $("#msg").val() });
            });

            // 私有消息
            $("#privatemsg").click(function () {
                connection.send({ type: 3, value: $("#user").val() + "|" + $("#message").val() });
            });

            // 加入组
            $('#join-group').click(function () {
                connection.send({ type: 4, value: $("#msg").val() });
            });

            // 离开组
            $('#leave-group').click(function () {
                connection.send({ type: 5, value: $("#msg").val() });
            });

            // 组消息
            $("#groupmsg").click(function () {
                connection.send({ type: 6, value: $("#user").val() + "|" + $("#message").val() });
            });

            // 停止连接
            $("#stopStart").click(function () {
                var $el = $(this);

                $el.prop("disabled", true);

                if ($.trim($el.find("span").text()) === "停止连接") {
                    connection.stop();
                } else {
                    start();
                }
            });

        });
    </script>
</asp:Content>